@@ -68,7 +68,7 @@ class VBox(BaseBox):
 # parent class only, you need to set the fields you want
 class VBoxForm(VBox):
     """
-    Basically,  a VBox, where all components(generally form stuff)
+    Basically, a VBox, where all components (generally form stuff)
     is wrapped in a <form> tag - important for bootstrap css
     """
 class SimpleApp(Widget):
@@ -140,9 +140,12 @@ class SimpleApp(Widget):
         ## set it to be false as soon as the callback is done
         if not self.name:
             return
+        to_delete = []
         for k in self.__dict__.keys():
             if k.startswith('_func'):
-                self.__dict__.pop(k)
+                to_delete.append(k)
+        for k in to_delete:
+            self.__dict__.pop(k)
         counter = 0
         if not self.update_registry.get(self.name):
             name = '_func%d'  % counter
@@ -181,7 +184,8 @@ class SimpleApp(Widget):
     def args_for_func(self, func):
         args = {}
         for k,v in self.widget_dict.items():
-            args[k] = v.value
+            if hasattr(v, 'value'):
+                args[k] = v.value
         args['app'] = self
         args = arg_filter(func, args)
         return args
@@ -200,7 +204,6 @@ class SimpleApp(Widget):
     def default_layout(self):
         widgets = [self.objects[x] for x in self.widget_list]
         widgets = VBoxForm(children=widgets)
-        output = self.objects['output']
         layout = AppHBox(children=[widgets, "output"], app=self)
         return layout
 
