@@ -2,7 +2,7 @@ from __future__ import division
 
 import numpy as np
 
-from bokeh.plotting import *
+from bokeh.plotting import figure, show, output_file
 
 N = 20
 img = np.empty((N,N), dtype=np.uint32)
